==> Shiira2.0src.zip: Shiira2.0src/shiira2/trunk/source/shelf/safariBookmark/SRSafariBookmarkShelf.h <==
/*
SRSafariBookmarkShelf.h

Author: Makoto Kinoshita

Copyright 2004-2006 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>
#import <WebKit/WebKit.h>
#import <HMDTAppKit/HMDTAppKit.h>
#import <HMDTWebKit/HMDTWebKit.h>

#import "SRShelf.h"

@interface SRSafariBookmarkShelf : SRShelf
{
    HMButton*       _tableButton;
    HMButton*       _browserButton;
    NSImageView*    _dividerViewView;
    HMMenuButton*   _contextButton;
    
    IBOutlet HMTreeController*      _bookmarkTreeController;
    
    IBOutlet HMSplitView*           _splitView;
    IBOutlet NSTabView*             _tabView;
    IBOutlet NSOutlineView*         _outlineView;
    IBOutlet NSBrowser*             _browser;
    
    IBOutlet HMScrollView*          _scrollView;
    IBOutlet HMColoredView*         _bookmarkView;
    IBOutlet HMColoredView*         _folderView;
    IBOutlet HMColoredView*         _javaScriptView;
    IBOutlet HMColoredView*         _smartView;
}

// Display style
- (void)setDisplayStyle:(int)displayStyle;

@end

==> Shiira2.2src.zip: Shiira2.2src/shiira2/trunk/source/shelf/safariBookmark/SRSafariBookmarkShelf.h <==
/*
SRSafariBookmarkShelf.h

Author: Makoto Kinoshita

Copyright 2004-2006 The Shiira Project. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are permitted 
provided that the following conditions are met:

  1. Redistributions of source code must retain the above copyright notice, this list of conditions 
  and the following disclaimer.

  2. Redistributions in binary form must reproduce the above copyright notice, this list of 
  conditions and the following disclaimer in the documentation and/or other materials provided 
  with the distribution.

THIS SOFTWARE IS PROVIDED BY THE SHIIRA PROJECT ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, 
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE SHIIRA PROJECT OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING 
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>
#import <WebKit/WebKit.h>
#import <HMDTAppKit/HMDTAppKit.h>
#import <HMDTWebKit/HMDTWebKit.h>

#import "SRShelf.h"

@interface SRSafariBookmarkShelf : SRShelf
{
    HMButton*       _tableButton;
    HMButton*       _browserButton;
    NSImageView*    _dividerViewView;
    HMMenuButton*   _contextButton;
    
    IBOutlet HMTreeController*      _bookmarkTreeController;
    
    IBOutlet HMSplitView*           _splitView;
    IBOutlet NSTabView*             _tabView;
    IBOutlet NSOutlineView*         _outlineView;
    IBOutlet NSBrowser*             _browser;
    
    IBOutlet HMScrollView*          _scrollView;
    
    IBOutlet HMColoredView*         _bookmarkView;
    
    IBOutlet HMColoredView*         _folderView;
    IBOutlet HMTextField*           _folderTitleTextField;
    IBOutlet NSButton*              _folderAutoTabCheckBox;
    
    IBOutlet HMColoredView*         _javaScriptView;
    
    IBOutlet HMColoredView*         _smartView;
}

// Display style
- (void)setDisplayStyle:(int)displayStyle;

@end
